==> pdf-lib-1.0.1.jar: META-INF/resources/webjars/pdf-lib/1.0.1/cjs/core/errors.d.ts <==
import PDFObject from "./objects/PDFObject";
export declare class MethodNotImplementedError extends Error {
    constructor(className: string, methodName: string);
}
export declare class PrivateConstructorError extends Error {
    constructor(className: string);
}
export declare class UnexpectedObjectTypeError extends Error {
    constructor(expected: any | any[], actual: any);
}
export declare class UnsupportedEncodingError extends Error {
    constructor(encoding: string);
}
export declare class ReparseError extends Error {
    constructor(className: string, methodName: string);
}
export declare class MissingCatalogError extends Error {
    constructor(ref?: PDFObject);
}
/***** Parser Errors ******/
export interface Position {
    line: number;
    column: number;
    offset: number;
}
export declare class NumberParsingError extends Error {
    constructor(pos: Position, value: string);
}
export declare class PDFParsingError extends Error {
    constructor(pos: Position, details: string);
}
export declare class NextByteAssertionError extends PDFParsingError {
    constructor(pos: Position, expectedByte: number, actualByte: number);
}
export declare class PDFObjectParsingError extends PDFParsingError {
    constructor(pos: Position, byte: number);
}
export declare class PDFInvalidObjectParsingError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class PDFStreamParsingError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class UnbalancedParenthesisError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class StalledParserError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class MissingPDFHeaderError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class MissingKeywordError extends PDFParsingError {
    constructor(pos: Position, keyword: number[]);
}
//# sourceMappingURL=errors.d.ts.map

==> pdf-lib-1.8.0.jar: META-INF/resources/webjars/pdf-lib/1.8.0/cjs/core/errors.d.ts <==
import PDFObject from "./objects/PDFObject";
export declare class MethodNotImplementedError extends Error {
    constructor(className: string, methodName: string);
}
export declare class PrivateConstructorError extends Error {
    constructor(className: string);
}
export declare class UnexpectedObjectTypeError extends Error {
    constructor(expected: any | any[], actual: any);
}
export declare class UnsupportedEncodingError extends Error {
    constructor(encoding: string);
}
export declare class ReparseError extends Error {
    constructor(className: string, methodName: string);
}
export declare class MissingCatalogError extends Error {
    constructor(ref?: PDFObject);
}
export declare class MissingPageContentsEmbeddingError extends Error {
    constructor();
}
export declare class UnrecognizedStreamTypeError extends Error {
    constructor(stream: any);
}
export declare class PageEmbeddingMismatchedContextError extends Error {
    constructor();
}
export declare class PDFArrayIsNotRectangleError extends Error {
    constructor(size: number);
}
export declare class InvalidPDFDateStringError extends Error {
    constructor(value: string);
}
export declare class InvalidTargetIndexError extends Error {
    constructor(targetIndex: number, Count: number);
}
export declare class CorruptPageTreeError extends Error {
    constructor(targetIndex: number, operation: string);
}
/***** Parser Errors ******/
export interface Position {
    line: number;
    column: number;
    offset: number;
}
export declare class NumberParsingError extends Error {
    constructor(pos: Position, value: string);
}
export declare class PDFParsingError extends Error {
    constructor(pos: Position, details: string);
}
export declare class NextByteAssertionError extends PDFParsingError {
    constructor(pos: Position, expectedByte: number, actualByte: number);
}
export declare class PDFObjectParsingError extends PDFParsingError {
    constructor(pos: Position, byte: number);
}
export declare class PDFInvalidObjectParsingError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class PDFStreamParsingError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class UnbalancedParenthesisError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class StalledParserError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class MissingPDFHeaderError extends PDFParsingError {
    constructor(pos: Position);
}
export declare class MissingKeywordError extends PDFParsingError {
    constructor(pos: Position, keyword: number[]);
}
//# sourceMappingURL=errors.d.ts.map
